@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
 
-import logging
-
 from tornado.tcpserver import TCPServer
 from tornado.ioloop import IOLoop
 
 from .callbacks_mixin import AppCallBacksMixin
 from .connection import Connection
+from vals import logger
 
 
 class Kola(TCPServer, AppCallBacksMixin):
@@ -24,6 +23,7 @@ class Kola(TCPServer, AppCallBacksMixin):
         self.conn_class = conn_class or Connection
 
         self.blueprints = dict()
+        self._configure_exc_handler()
 
     def handle_stream(self, stream, address):
         self.conn_class(self, stream, address)
@@ -34,3 +34,12 @@ class Kola(TCPServer, AppCallBacksMixin):
 
     def register_blueprint(self, blueprint):
         blueprint.register2app(self)
+
+    def _configure_exc_handler(self):
+        """
+        因为tornado的默认handler的log不一定会被配置
+        """
+        def exc_handler(callback):
+            logger.error("Exception in callback %r", callback, exc_info=True)
+
+        IOLoop.instance().handle_callback_exception = exc_handler
