@@ -10,5 +10,4 @@ def safe_call(func, *args, **kwargs):
     try:
         return func(*args, **kwargs)
     except Exception, e:
-        logger.error('func raise exception. func: %s, e: %s, traceback: %s',
-                     func.__name__, e, __import__('traceback').format_exc())
+        logger.exception('func raise exception. func: %s', func.__name__)
